# 1.0.4

  * First logged. Apart from code errors, the outline defines the "first" file format.
  * Quiet option and "some" of the compresslevel used, although not yet block or dict size.
  * Build process of python package decided, but might need tunning going forward.